@@ -4,15 +4,17 @@
 
 import json
 import logging
-import requests
-from .data import Address, Location, LocationCollection
-from .exceptions import (GeocodioAuthError, GeocodioDataError,
-        GeocodioServerError, GeocodioError)
 
+import requests
+
+from geocodio.data import Address
+from geocodio.data import Location
+from geocodio.data import LocationCollection
+from geocodio import exceptions
 
 logger = logging.getLogger(__name__)
 
-ALLOWED_FIELDS = ['cd', 'cd13', 'stateleg', 'school', 'timezone']
+ALLOWED_FIELDS = ['cd', 'cd113', 'cd114', 'cd115', 'cd116', 'census', 'stateleg', 'school', 'timezone']
 
 
 def protect_fields(f):
@@ -30,13 +32,13 @@ def error_response(response):
     Raises errors matching the response code
     """
     if response.status_code >= 500:
-        raise GeocodioServerError
+        raise exceptions.GeocodioServerError
     elif response.status_code == 403:
-        raise GeocodioAuthError
+        raise exceptions.GeocodioAuthError
     elif response.status_code == 422:
-        raise GeocodioDataError(response.json()['error'])
+        raise exceptions.GeocodioDataError(response.json()['error'])
     else:
-        raise GeocodioError("Unknown service error (HTTP {0})".format(response.status_code))
+        raise exceptions.GeocodioError("Unknown service error (HTTP {0})".format(response.status_code))
 
 
 def json_points(points):
@@ -54,7 +56,7 @@ class GeocodioClient(object):
     """
     Client connection for Geocod.io API
     """
-    BASE_URL = "http://api.geocod.io/v1/{verb}"
+    BASE_URL = "http://api.geocod.io/v1.2/{verb}"
 
     def __init__(self, key, order='lat'):
         """
@@ -107,7 +109,7 @@ class GeocodioClient(object):
         Returns an Address dictionary with the components of the queried
         address.
         """
-        fields = kwargs.pop('fields', [])
+        fields = ",".join(kwargs.pop('fields', []))
         response = self._req('post', verb="geocode", params={'fields': fields},
                              data=json.dumps(addresses))
         if response.status_code != 200:
@@ -169,7 +171,7 @@ class GeocodioClient(object):
             ]
         }
         """
-        fields = kwargs.pop('fields', [])
+        fields = ",".join(kwargs.pop('fields', []))
         response = self._req(verb="geocode", params={'q': address, 'fields': fields})
         if response.status_code != 200:
             return error_response(response)
@@ -183,17 +185,16 @@ class GeocodioClient(object):
 
         Provides a single point of access for end users.
         """
-        fields = kwargs.pop('fields', [])
         if isinstance(address_data, list):
-            return self.batch_geocode(address_data, fields=fields)
-        return self.geocode_address(address_data, fields=fields)
+            return self.batch_geocode(address_data, **kwargs)
+        return self.geocode_address(address_data, **kwargs)
 
     @protect_fields
     def reverse_point(self, latitude, longitude, **kwargs):
         """
         Method for identifying an address from a geographic point
         """
-        fields = kwargs.pop('fields', [])
+        fields = ",".join(kwargs.pop('fields', []))
         point_param = "{0},{1}".format(latitude, longitude)
         response = self._req(verb="reverse", params={'q': point_param, 'fields': fields})
         if response.status_code != 200:
@@ -205,7 +206,7 @@ class GeocodioClient(object):
         """
         Method for identifying the addresses from a list of lat/lng tuples
         """
-        fields = kwargs.pop('fields', [])
+        fields = ",".join(kwargs.pop('fields', []))
         response = self._req("post", verb="reverse", params={'fields': fields},
                              data=json_points(points))
         if response.status_code != 200:
